Learn R Programming

slam (version 0.1-47)

sums: Form Row and Column Sums and Means

Description

Form row and column sums and means for sparse arrays (currently simple_triplet_matrix only).

Usage

row_sums(x, na.rm = FALSE, dims = 1, …)
col_sums(x, na.rm = FALSE, dims = 1, …)
row_means(x, na.rm = FALSE, dims = 1, …)
col_means(x, na.rm = FALSE, dims = 1, …)

# S3 method for simple_triplet_matrix row_sums(x, na.rm = FALSE, dims = 1, …) # S3 method for simple_triplet_matrix col_sums(x, na.rm = FALSE, dims = 1, …) # S3 method for simple_triplet_matrix row_means(x, na.rm = FALSE, dims = 1, …) # S3 method for simple_triplet_matrix col_means(x, na.rm = FALSE, dims = 1, …)

Arguments

x

a sparse array containing numeric, integer, or logical values.

na.rm

logical. Should missing values (including NaN) be omitted from the calculations?

dims

currently not used for sparse arrays.

…

currently not used for sparse arrays.

Value

A numeric (double) array of suitable size, or a vector if the result is one-dimensional. The dimnames (or names for a vector result) are taken from the original array.

Details

Provides fast summation over the rows or columns of sparse matrices in simple_triplet-form.

See Also

simple_triplet_matrix, colSums for dense numeric arrays.

Examples

Run this code
# NOT RUN {
##
x <- matrix(c(1, 0, 0, 2, 1, NA), nrow = 3)
x
s <- as.simple_triplet_matrix(x)
row_sums(s)
row_sums(s, na.rm = TRUE)
col_sums(s)
col_sums(s, na.rm = TRUE)
# }

Run the code above in your browser using DataLab